(hickory-to-xhtml dom)Given a hickory HTML DOM map structure (as returned by as-hickory), returns a string containing HTML it represents. Keep in mind this function is not super fast or heavy-duty.
Note that it will NOT in general be the case that
(= my-html-src (hickory-to-html (as-hickory (parse my-html-src))))
as we do not keep any letter case or whitespace information, any "tag-soupy" elements, attribute quote characters used, etc.
Given a hickory HTML DOM map structure (as returned by as-hickory), returns a string containing HTML it represents. Keep in mind this function is not super fast or heavy-duty. Note that it will NOT in general be the case that (= my-html-src (hickory-to-html (as-hickory (parse my-html-src)))) as we do not keep any letter case or whitespace information, any "tag-soupy" elements, attribute quote characters used, etc.
(parse-xml data)use Jsoap.Parser.xmlParser to parse a given xml string
use Jsoap.Parser.xmlParser to parse a given xml string
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |