(create-page connection spacename parentpage pagetitle pagecontent)create page
create page
(delete-childs connection spacename pagetitle)(delete-childs connection spacename pagetitle purge)delete child pages (which have to be leafs)
delete child pages (which have to be leafs)
(delete-childs-recursive connection spacename pageid)(delete-childs-recursive connection spacename pageid purge)delete child pages recursive
delete child pages recursive
(delete-page connection spacename pageid)(delete-page connection spacename pageid purge)delete (purge-delete) page
delete (purge-delete) page
(find-page connection spacename title)find single (first) page by spacename and title
find single (first) page by spacename and title
(find-page-by-tags connection spacename tags)find page by tags
find page by tags
(find-pages connection spacename title)find pages by spacename and title
find pages by spacename and title
(get-child-ids connection spacename pageid)returns list of child page ids
returns list of child page ids
(get-childs connection spacename pageid)returns list of child pages
returns list of child pages
(get-page connection spacename title)get page by spacename and title
get page by spacename and title
(get-page-body connection spacename title)get page body by spacename and title
get page body by spacename and title
(get-page-hiccup connection spacename title)get page body as hiccup structure by spacename and title
get page body as hiccup structure by spacename and title
(get-page-storage connection spacename title)get page body as hickory structure by spacename and title
get page body as hickory structure by spacename and title
(get-page-version connection spacename title)get page by spacename and title
get page by spacename and title
(has-childs? connection spacename pageid)check if page has child pages
check if page has child pages
(page-exists? connection spacename pagename)check if page exists
check if page exists
(search-page connection cql)(upcreate-page connection spacename parentpage pagetitle pagecontent)update or create a page
update or create a page
(update-page connection spacename pagetitle pagecontent)update page
update page
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |