(get-ac-parameter loc paramname)extract first parameter from :ac:parameter element
extract first parameter from `:ac:parameter` element
(process-structured-macros root-loc process)search for :ac:structured-macro entries and process each element.
root-loc zip location to start the search <br>
process function which will be called to process the found element
if process returns nil: the node will be removed<br> else: the node will be replaced with the returned result
search for `:ac:structured-macro` entries and process each element. `root-loc` zip location to start the search <br> `process` function which will be called to process the found element *if* process returns nil: the node will be removed<br> *else:* the node will be replaced with the returned result
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |